// types/room.ts
import { UserInfo } from './user';
// 房间角色
export enum RoomRole {
  HOSTER = 'hoster',
  PLAYER = 'player'
}

// 房间可见性
export enum RoomVisibility {
  PUBLIC = 'public',
  PRIVATE = 'private'
}

// 房间状态
export enum RoomStatus {
  WAITING = 'waiting',
  PLAYING = 'playing',
  ENDED = 'ended'
}

// 游戏房间用户
export interface RoomUserInfo extends UserInfo {
  roomRole: RoomRole;        // 在房间中的角色
  joinTime: number;      // 加入时间
  isReady?: boolean;     // 是否准备好
}

// 游戏房间
export interface Room {
  id: string;            // 房间唯一ID
  name: string;          // 房间名称
  gameId: string;        // 游戏ID
  gameTitle: string;     // 游戏标题
  maxPlayers: number;    // 最大玩家数
  visibility: RoomVisibility;  // 可见性
  password?: string;     // 可选密码
  hosterId: string;      // 房主ID
  createTime: number;    // 创建时间
  startTime?: number;    // 开始时间
  endTime?: number;      // 结束时间
  status: RoomStatus;    // 房间状态
  users: RoomUserInfo[];     // 房间内用户列表
}

// 最近房间记录
export interface RecentRoom {
  id: string;            // 房间ID
  name: string;          // 房间名称
  gameTitle: string;     // 游戏标题
  lastVisitTime: number; // 最后访问时间
  hasPassword: boolean;  // 是否有密码
  status: RoomStatus;    // 房间状态
  playerCount: number;   // 玩家数量
}